==> ocre_v0_033.tgz: ocre-0.033/ocre/src/segmenta3.c <==

#include <libintl.h>
#include <locale.h>
#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "aplica.h"
#include "config.h"
#include "estad.h"
#include "glifos.h"
#include "grises.h"
#include "histos.h"
#include "inclina.h"
#include "imag.h"
// #include "imagio.h"
// #include "imagx.h"
#include "lectura.h"
#include "line.h"
#include "opcns.h"
// #include "segmenta0.h"
#include "segmenta.h"
#include "segmenta3.h"

// comienzo_local

void tipoDocumento (ttdocum *tdocum, tvent vent)
{
  lista lineasHagr ;
  lista lineasVagr ;
  prepara0 (vent);
  sigueyAgrupaRayasHor (&lineasHagr, vent);
//  printf ("rayas n. horizonatales\n");
//  imprimeRayas (lineasHagr);
//
  sigueyAgrupaRayasVer (&lineasVagr, vent);
//  printf ("rayas n. verticales\n");
//  imprimeRayas (lineasVagr);
//
  *tdocum = tdocumNoclasif;
  if ((longLista(lineasHagr) > 0) ||
      (longLista(lineasVagr) > 0) )
    *tdocum = tdocumTabloide;
    *tdocum = tdocumNoclasif;
//    *tdocum = tdocumTabloide;
}

void leedeColumnas (tglifo *nglifoH, tvent vent, int *n)
{
  tglifo glifoHoja;
  tnodol nodol;
  lista columnas;
  tglifo glifoCol;
  glifoHoja = glifoCompPaginaNuevo ();
  casaGlifoVent (glifoHoja, vent);
  columnas = vent->lvint;
  for (nodol = columnas->primero; nodol != (tnodol)0L; nodol = nodol->siguiente) {
	  //             ......
    tvent ventcol;
//  int nh;
    ventcol = (tvent) nodol->aitem;
//  presentaVentana (&nh, ventcol, "sal36e.pgm", 1); para (); exit (0);
    segmReconoceyRepasaColumnaP (&glifoCol, ventcol, n);
    adoptaGlifo (glifoHoja, glifoCol);
    casaGlifoVent (glifoCol, ventcol);
    }
  *nglifoH = glifoHoja;
}

void segmentaTabloide (tvent vent, tvent *nventcuer)
{
  lista lineasHagr ;
  lista lineasVagr ;
  lista lineasHblanAgr ;
  tvent ventcuer;
  int hisV[MAXPIXV];
  int hisH[MAXPIXH];
  int hisHpr[MAXPIXH];
  int hisVpr[MAXPIXH];
  int incly_64k, incl_64k;
  prepara0 (vent);
  sigueyAgrupaRayasHor (&lineasHagr, vent);
  //  imprimeRayasCab (lineasHagr, "rayas n. horizonatales");
  sigueyAgrupaRayasVer (&lineasVagr, vent);
  //  imprimeRayasCab (lineasVagr, "rayas n. verticales");
  sigueyAgrupaRayasHorBlan (&lineasHblanAgr, vent, (vent->tx * 31)/ 32);
  //  imprimeRayasCab (lineasHblanAgr, "rayas blancas horizonatales");
  incl_64k= calculaInclinacionH (vent);
  //  printf("incl_64k %4d\n", incl_64k);
  histoHorInclLinb (hisH, vent, incl_64k, 30);
  aplicaV (hisH, hisHpr, vent->ty, 8, prom);
  //  presentaHistoHorH (&nh, hisHpr, vent, "sal36h.dat", "sal36h.gpt");
  giroPeqH (vent, incl_64k);
  //
  segmentaPiedepag (vent, hisH, incl_64k);
  ventcuer = seleccionaSubventana (vent, "car");
  //
  prepara0 (ventcuer);
  incly_64k = calculaInclinacionV (ventcuer);
  //
  printf("incly_64k %4d\n", incly_64k);
  //
  histoVerInclLinb (hisV, ventcuer, incly_64k, 10);
  aplicaV (hisV, hisVpr, ventcuer->tx, 8, prom);
  //
  //  escribeCaracHistoGr (carhisgrDeVentana(ventcuer));
  segmentaCols (ventcuer, hisV, incly_64k);
  *nventcuer = ventcuer;
}

void segmentayLeeTabloide (tglifo *nglifoH, tvent vent, int *n)
{
  tvent ventcuer;
  segmentaTabloide (vent, &ventcuer);
  leedeColumnas (nglifoH, ventcuer, n);
}

==> ocre_v0_039.tgz: ocre-0.039/ocre/src/segmenta3.c <==

#include <libintl.h>
#include <locale.h>
#define _(mens) gettext(mens)
#define N_(mens) (mens)

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "aplica.h"
#include "config.h"
#include "estad.h"
#include "glifos.h"
#include "grises.h"
#include "histos.h"
#include "inclina.h"
#include "imag.h"
// #include "imagio.h"
// #include "imagx.h"
#include "lectura.h"
#include "line.h"
#include "opcns.h"
// #include "segmenta0.h"
#include "segmenta.h"
#include "segmenta3.h"

// comienzo_local

void tipoDocumento (ttdocum *tdocum, tvent vent)
{
  lista lineasHagr ;
  lista lineasVagr ;
  prepara0 (vent);
  sigueyAgrupaRayasHor (&lineasHagr, vent);
//  printf ("rayas n. horizonatales\n");
//  imprimeRayas (lineasHagr);
//
  sigueyAgrupaRayasVer (&lineasVagr, vent);
//  printf ("rayas n. verticales\n");
//  imprimeRayas (lineasVagr);
//
  *tdocum = tdocumNoclasif;
  if ((longLista(lineasHagr) > 0) ||
      (longLista(lineasVagr) > 0) )
    *tdocum = tdocumTabloide;
    *tdocum = tdocumNoclasif;
//    *tdocum = tdocumTabloide;
}

void leedeColumnas (tglifo *nglifoH, tvent vent, int *n)
{
  tglifo glifoHoja;
  tnodol nodol;
  lista columnas;
  tglifo glifoCol;
  glifoHoja = glifoCompPaginaNuevo ();
  casaGlifoVent (glifoHoja, vent);
  columnas = vent->lvint;
  for (nodol = columnas->primero; nodol != (tnodol)0L; nodol = nodol->siguiente) {
	  //             ......
    tvent ventcol;
//  int nh;
    ventcol = (tvent) nodol->aitem;
//  presentaVentana (&nh, ventcol, "sal36e.pgm", 1); para (); exit (0);
    segmReconoceRepasayEscribeColumnaP (&glifoCol, ventcol, n);
    adoptaGlifo (glifoHoja, glifoCol);
    casaGlifoVent (glifoCol, ventcol);
    }
  *nglifoH = glifoHoja;
}

void segmentaTabloide (tvent vent, tvent *nventcuer)
{
  lista lineasHagr ;
  lista lineasVagr ;
  lista lineasHblanAgr ;
  tvent ventcuer;
  int hisV[MAXPIXV];
  int hisH[MAXPIXH];
  int hisHpr[MAXPIXH];
  int hisVpr[MAXPIXH];
  int incly_64k, incl_64k;
  prepara0 (vent);
  sigueyAgrupaRayasHor (&lineasHagr, vent);
  //  imprimeRayasCab (lineasHagr, "rayas n. horizonatales");
  sigueyAgrupaRayasVer (&lineasVagr, vent);
  //  imprimeRayasCab (lineasVagr, "rayas n. verticales");
  sigueyAgrupaRayasHorBlan (&lineasHblanAgr, vent, (vent->tx * 31)/ 32);
  //  imprimeRayasCab (lineasHblanAgr, "rayas blancas horizonatales");
  incl_64k= calculaInclinacionH (vent);
  //  printf("incl_64k %4d\n", incl_64k);
  histoHorInclLinb (hisH, vent, incl_64k, 30);
  aplicaV (hisH, hisHpr, vent->ty, 8, prom);
  //  presentaHistoHorH (&nh, hisHpr, vent, "sal36h.dat", "sal36h.gpt");
  giroPeqH (vent, incl_64k);
  //
  segmentaPiedepag (vent, hisH, incl_64k);
  ventcuer = seleccionaSubventana (vent, "car");
  //
  prepara0 (ventcuer);
  incly_64k = calculaInclinacionV (ventcuer);
  //
  printf("incly_64k %4d\n", incly_64k);
  //
  histoVerInclLinb (hisV, ventcuer, incly_64k, 10);
  aplicaV (hisV, hisVpr, ventcuer->tx, 8, prom);
  //
  //  escribeCaracHistoGr (carhisgrDeVentana(ventcuer));
  segmentaCols (ventcuer, hisV, incly_64k);
  *nventcuer = ventcuer;
}

void segmentayLeeTabloide (tglifo *nglifoH, tvent vent, int *n)
{
  tvent ventcuer;
  segmentaTabloide (vent, &ventcuer);
  leedeColumnas (nglifoH, ventcuer, n);
}
